@@ -1,5 +1,5 @@
 /*
- *  This file is part of nzbget. See <http://nzbget.net>.
+ *  This file is part of nzbget. See <https://nzbget.com>.
  *
  *  Copyright (C) 2013-2016 Andrey Prygunkov <hugbug@users.sourceforge.net>
  *
@@ -51,7 +51,7 @@ bool FeedFilter::Term::MatchValue(const char* strValue, int64 intValue)
 
 	if (m_command < fcEqual && !strValue)
 	{
-		intBuf.Format("%lld", intValue);
+		intBuf.Format("%" PRId64, intValue);
 		strValue = intBuf;
 	}
 
