@@ -3,7 +3,7 @@
  *
  *  Copyright (C) 2004 Sven Henkel <sidddy@users.sourceforge.net>
  *  Copyright (C) 2007-2019 Andrey Prygunkov <hugbug@users.sourceforge.net>
- *  Copyright (C) 2024 Denis <denis@nzbget.com>
+ *  Copyright (C) 2024-2025 Denis <denis@nzbget.com>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -180,15 +180,15 @@ public:
 	bool GetReloading() { return m_reloading; }
 
 	// Options::Extender
-	virtual void AddNewsServer(int id, bool active, const char* name, const char* host,
+	void AddNewsServer(int id, bool active, const char* name, const char* host,
 		int port, int ipVersion, const char* user, const char* pass, bool joinGroup,
 		bool tls, const char* cipher, int maxConnections, int retention,
-		int level, int group, bool optional, unsigned int certVerificationfLevel);
-	virtual void AddFeed(int id, const char* name, const char* url, int interval,
+		int level, int group, bool optional, unsigned int certVerificationfLevel) override;
+	void AddFeed(int id, const char* name, const char* url, int interval,
 		const char* filter, bool backlog, bool pauseNzb, const char* category,
-		int priority, const char* feedScript);
-	virtual void AddTask(int id, int hours, int minutes, int weekDaysBits,
-		Options::ESchedulerCommand command, const char* param);
+		FeedInfo::CategorySource categorySource, int priority, const char* feedScript) override;
+	void AddTask(int id, int hours, int minutes, int weekDaysBits,
+		Options::ESchedulerCommand command, const char* param) override;
 #ifdef WIN32
 	virtual void SetupFirstStart();
 #endif
@@ -1073,10 +1073,10 @@ void NZBGet::AddNewsServer(int id, bool active, const char* name, const char* ho
 }
 
 void NZBGet::AddFeed(int id, const char* name, const char* url, int interval, const char* filter,
-	bool backlog, bool pauseNzb, const char* category, int priority, const char* feedScript)
+	bool backlog, bool pauseNzb, const char* category, FeedInfo::CategorySource categorySource, int priority, const char* feedScript)
 {
 	m_feedCoordinator->AddFeed(std::make_unique<FeedInfo>(id, name, url, backlog, interval, filter,
-		pauseNzb, category, priority, feedScript));
+		pauseNzb, category, categorySource, priority, feedScript));
 }
 
 void NZBGet::AddTask(int id, int hours, int minutes, int weekDaysBits,
