@@ -1,8 +1,9 @@
 /*
- *  This file is part of nzbget. See <http://nzbget.net>.
+ *  This file is part of nzbget. See <https://nzbget.com>.
  *
  *  Copyright (C) 2004 Sven Henkel <sidddy@users.sourceforge.net>
  *  Copyright (C) 2007-2016 Andrey Prygunkov <hugbug@users.sourceforge.net>
+ *  Copyright (C) 2024 Denis <denis@nzbget.com>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -15,7 +16,7 @@
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ *  along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 
@@ -30,6 +31,25 @@ void ServerPool::PooledConnection::SetFreeTimeNow()
 	m_freeTime = Util::CurrentTime();
 }
 
+NewsServer* ServerPool::GetServerById(int id)
+{
+	auto serverIt = std::find_if(
+		begin(m_servers),
+		end(m_servers),
+		[&](const std::unique_ptr<NewsServer>& server)
+		{
+			return server->GetId() == id;
+		}
+	);
+
+	if (serverIt != end(m_servers))
+	{
+		return serverIt->get();
+	}
+
+	return nullptr;
+}
+
 
 void ServerPool::AddServer(std::unique_ptr<NewsServer> newsServer)
 {
