@@ -1,5 +1,5 @@
 /*
- *  This file is part of nzbget. See <http://nzbget.net>.
+ *  This file is part of nzbget. See <https://nzbget.com>.
  *
  *  Copyright (C) 2015-2016 Andrey Prygunkov <hugbug@users.sourceforge.net>
  *
@@ -34,7 +34,8 @@ public:
 	static bool SizeDiffOK(int64 size1, int64 size2, int maxDiffPercent);
 
 protected:
-	virtual void PrintMessage(Message::EKind kind, const char* format, ...) PRINTF_SYNTAX(3) {}
+	virtual void PrintMessage([[maybe_unused]] Message::EKind kind,
+		[[maybe_unused]] const char* format, ...) PRINTF_SYNTAX(3) {}
 
 private:
 	CString m_destDir;
