@@ -1,5 +1,5 @@
 /*
- *  This file is part of nzbget. See <http://nzbget.net>.
+ *  This file is part of nzbget. See <https://nzbget.com>.
  *
  *  Copyright (C) 2007-2016 Andrey Prygunkov <hugbug@users.sourceforge.net>
  *
@@ -21,17 +21,17 @@
 #ifndef PARPARSER_H
 #define PARPARSER_H
 
-#include "NString.h"
+#include <string>
 #include "Container.h"
 
 class ParParser
 {
 public:
-	typedef std::vector<CString> ParFileList;
+	typedef std::vector<std::string> ParFileList;
 
 	static bool FindMainPars(const char* path, ParFileList* fileList);
-	static bool ParseParFilename(const char* parFilename, int* baseNameLen, int* blocks);
-	static bool SameParCollection(const char* filename1, const char* filename2);
+	static bool ParseParFilename(const char* parFilename, bool confirmedFilename, int* baseNameLen, int* blocks);
+	static bool SameParCollection(const char* filename1, const char* filename2, bool confirmedFilenames);
 };
 
 #endif
