@@ -1,5 +1,5 @@
 /*
- *  This file is part of nzbget. See <http://nzbget.net>.
+ *  This file is part of nzbget. See <https://nzbget.com>.
  *
  *  Copyright (C) 2007-2016 Andrey Prygunkov <hugbug@users.sourceforge.net>
  *
@@ -39,11 +39,13 @@ public:
 	void NzbDownloaded(DownloadQueue* downloadQueue, NzbInfo* nzbInfo);
 
 protected:
-	virtual void Update(Subject* caller, void* aspect) { DownloadQueueUpdate(aspect); }
+	virtual void Update([[maybe_unused]] Subject* caller, void* aspect) { DownloadQueueUpdate(aspect); }
 
 private:
 	int m_queuedJobs = 0;
 	RawNzbList m_activeJobs;
+	Mutex m_waitMutex;
+	ConditionVar m_waitCond;
 
 	void CheckPostQueue();
 	void CheckRequestPar(DownloadQueue* downloadQueue);
