@@ -1,7 +1,8 @@
 /*
- *  This file is part of nzbget. See <http://nzbget.net>.
+ *  This file is part of nzbget. See <https://nzbget.com>.
  *
  *  Copyright (C) 2007-2017 Andrey Prygunkov <hugbug@users.sourceforge.net>
+ *  Copyright (C) 2024 Denis <denis@nzbget.com>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -14,13 +15,18 @@
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ *  along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 
 #include "nzbget.h"
 #include "FileSystem.h"
 #include "Util.h"
+#include "Log.h"
+
+#ifdef WIN32
+#include "utf8.h"
+#endif
 
 const char* RESERVED_DEVICE_NAMES[] = { "CON", "PRN", "AUX", "NUL",
 	"COM1", "COM2", "COM3", "COM4", "COM5", "COM6", "COM7", "COM8", "COM9",
@@ -54,7 +60,49 @@ void FileSystem::NormalizePathSeparators(char* path)
 	}
 }
 
+std::optional<std::string> FileSystem::GetRealPath(const std::string& path)
+{
+	if (path.empty()) return std::nullopt;
+
 #ifdef WIN32
+	auto res = Utf8::Utf8ToWide(path);
+	if (!res.has_value()) return std::nullopt;
+
+	std::wstring wpath = std::move(res.value());
+
+	if (wpath.size() > MAX_DIR_PATH && std::wcsncmp(wpath.c_str(), L"\\\\", 2) == 0)
+	{
+		wpath = L"\\\\?\\UNC" + wpath;
+	}
+	else if (wpath.size() > MAX_DIR_PATH)
+	{
+		wpath = L"\\\\?\\" + wpath;
+	}
+
+	DWORD len = GetFullPathNameW(wpath.c_str(), 0, nullptr, nullptr);
+	if (len == 0) return std::nullopt;
+
+	std::wstring buffer(len, '\0');
+	len = GetFullPathNameW(wpath.c_str(), len, &buffer[0], nullptr);
+	if (len == 0) return std::nullopt;
+
+	return Utf8::WideToUtf8(buffer);
+#else
+	if (char* realPath = realpath(path.c_str(), nullptr))
+	{
+		std::string res = realPath;
+		free(realPath);
+		return res;
+	}
+#endif
+
+	return std::nullopt;
+}
+
+#ifdef WIN32
+
+const size_t FileSystem::MAX_DIR_PATH = 248;
+
 bool FileSystem::ForceDirectories(const char* path, CString& errmsg)
 {
 	errmsg.Clear();
@@ -252,7 +300,7 @@ bool FileSystem::SaveBufferIntoFile(const char* filename, const char* buffer, in
 	return writtenBytes == bufLen;
 }
 
-bool FileSystem::AllocateFile(const char* filename, int64 size, bool sparse, CString& errmsg)
+bool FileSystem::AllocateFile(const char* filename, int64 size, [[maybe_unused]] bool sparse, CString& errmsg)
 {
 	errmsg.Clear();
 	bool ok = false;
@@ -304,10 +352,29 @@ bool FileSystem::AllocateFile(const char* filename, int64 size, bool sparse, CSt
 			errmsg = GetLastErrorMessage();
 			return false;
 		}
-		char c = '0';
-		fwrite(&c, 1, size, file);
+
+		// write zeros in 16K chunks
+		CharBuffer zeros(16 * 1024);
+		memset(zeros, 0, zeros.Size());
+		for (int64 remaining = size; remaining > 0;)
+		{
+			int64 needbytes = std::min(remaining, (int64)zeros.Size());
+			int64 written = fwrite(zeros, 1, needbytes, file);
+			if (written != needbytes)
+			{
+				errmsg = GetLastErrorMessage();
+				fclose(file);
+				return false;
+			}
+			remaining -= written;
+		}
 		fclose(file);
+
 		ok = FileSize(filename) == size;
+		if (!ok)
+		{
+			errmsg = "created file has wrong size";
+		}
 	}
 #endif
 	return ok;
@@ -347,6 +414,21 @@ char* FileSystem::BaseFileName(const char* filename)
 	}
 }
 
+std::pair<std::string, std::string> FileSystem::SplitPathAndFilename(const std::string& fullPath)
+{
+	size_t lastSlashPos = fullPath.find_last_of("/\\");
+
+	if (lastSlashPos == std::string::npos)
+	{
+		return std::make_pair(fullPath, "");
+	}
+
+	std::string path = fullPath.substr(0, lastSlashPos);
+	std::string filename = fullPath.substr(lastSlashPos + 1);
+
+	return std::make_pair(std::move(path), std::move(filename));
+}
+
 bool FileSystem::ReservedChar(char ch)
 {
 	if ((unsigned char)ch < 32)
@@ -428,7 +510,7 @@ CString FileSystem::MakeUniqueFilename(const char* destDir, const char* basename
 		if (extension && extension != basename)
 		{
 			BString<1024> filenameWithoutExt = basename;
-			int end = extension - basename;
+			int end = (int)(extension - basename);
 			filenameWithoutExt[end < 1024 ? end : 1024-1] = '\0';
 
 			if (!strcasecmp(extension, ".par2"))
@@ -501,6 +583,7 @@ bool FileSystem::CopyFile(const char* srcFilename, const char* dstFilename)
 bool FileSystem::DeleteFile(const char* filename)
 {
 #ifdef WIN32
+	SetFileAttributes(filename, FILE_ATTRIBUTE_NORMAL);
 	return _wremove(UtfPathToWidePath(filename)) == 0;
 #else
 	return remove(filename) == 0;
@@ -573,6 +656,47 @@ bool FileSystem::RemoveDirectory(const char* dirFilename)
 #endif
 }
 
+
+std::string FileSystem::ExtractFilePathFromCmd(const std::string& path)
+{
+	if (path.empty())
+	{
+		return path;
+	}
+
+	size_t lastSeparatorPos = path.find_last_of(PATH_SEPARATOR);
+	if (lastSeparatorPos != std::string::npos)
+	{
+		size_t possibleKeysPos = path.find(" ", lastSeparatorPos);
+
+		if (possibleKeysPos != std::string::npos)
+		{
+			return path.substr(0, possibleKeysPos);
+		}
+	}
+
+	return path;
+}
+
+std::string FileSystem::EscapePathForShell(const std::string& path)
+{
+	if (path.empty())
+	{
+		return path;
+	}
+
+	return "\"" + path + "\"";
+}
+
+std::optional<std::string> FileSystem::GetFileExtension(const std::string& filename)
+{
+	size_t extIdx = filename.rfind(".");
+	if (extIdx == std::string::npos)
+		return std::nullopt;
+
+	return filename.substr(extIdx);
+}
+
 /* Delete directory which is empty or contains only hidden files or directories (whose names start with dot) */
 bool FileSystem::DeleteDirectory(const char* dirFilename)
 {
@@ -663,22 +787,28 @@ int64 FileSystem::FileSize(const char* filename)
 #endif
 }
 
-int64 FileSystem::FreeDiskSize(const char* path)
+std::optional<FileSystem::DiskState> FileSystem::GetDiskState(const char* path)
 {
 #ifdef WIN32
-	ULARGE_INTEGER free, dummy;
-	if (GetDiskFreeSpaceEx(path, &free, &dummy, &dummy))
+	ULARGE_INTEGER freeBytesAvailable;
+	ULARGE_INTEGER totalNumberOfBytes;
+
+	if (GetDiskFreeSpaceEx(path, &freeBytesAvailable, &totalNumberOfBytes, nullptr))
 	{
-		return free.QuadPart;
+		int64 available = Util::SafeIntCast<uint64, int64>(freeBytesAvailable.QuadPart);
+		int64 total = Util::SafeIntCast<uint64, int64>(totalNumberOfBytes.QuadPart);
+		return FileSystem::DiskState{ available, total };
 	}
 #else
 	struct statvfs diskdata;
 	if (!statvfs(path, &diskdata))
 	{
-		return (int64)diskdata.f_frsize * (int64)diskdata.f_bavail;
+		int64 available = Util::SafeIntCast<uint64, int64>(diskdata.f_bavail * diskdata.f_frsize);
+		int64 total = Util::SafeIntCast<uint64, int64>(diskdata.f_blocks * diskdata.f_frsize);
+		return FileSystem::DiskState{ available, total };
 	}
 #endif
-	return -1;
+	return std::nullopt;
 }
 
 bool FileSystem::RenameBak(const char* filename, const char* bakPart, bool removeOldExtension, CString& newName)
@@ -926,6 +1056,9 @@ bool FileSystem::FlushDirBuffers(const char* filename, CString& errmsg)
 }
 
 #ifndef WIN32
+
+mode_t FileSystem::uMask;
+
 void FileSystem::FixExecPermission(const char* filename)
 {
 	struct stat buffer;
@@ -936,6 +1069,62 @@ void FileSystem::FixExecPermission(const char* filename)
 		chmod(filename, buffer.st_mode);
 	}
 }
+
+bool FileSystem::RestoreFileOrDirPermissions(const char* filename) 
+{
+	struct stat buffer;
+	int ec = stat(filename, &buffer);
+	if (ec != 0) 
+	{
+
+#ifdef DEBUG
+		debug("Failed to read information for %s. Errno: %i", filename, ec);
+#endif
+
+		return false;
+	}
+
+	if (S_ISDIR(buffer.st_mode)) 
+	{
+		return RestoreDirPermissions(filename);
+	} 
+
+	return RestoreFilePermissions(filename);
+}
+
+bool FileSystem::RestoreFilePermissions(const char* filepath)
+{
+	mode_t mode = S_IRUSR | S_IWUSR | S_IRGRP | S_IWGRP | S_IROTH | S_IWOTH; // 0666
+	return RestorePermissions(filepath, mode);
+}
+
+bool FileSystem::RestoreDirPermissions(const char* filename)
+{
+	mode_t mode = S_IRWXU | S_IRWXG | S_IRWXO; // 0777
+	return RestorePermissions(filename, mode);
+}
+
+bool FileSystem::RestorePermissions(const char* filename, mode_t mode) 
+{
+	mode_t permissions = mode & ~FileSystem::uMask;
+	int ec = chmod(filename, permissions);
+	if (ec == 0)
+	{
+
+#ifdef DEBUG
+		debug("Permissions %o was set for %s", permissions, filename);
+#endif
+
+		return true;
+	} 
+
+#ifdef DEBUG
+	debug("Failed to set permissions for %s. Errno %i", filename, ec);
+#endif
+
+	return false;
+}
+
 #endif
 
 #ifdef WIN32
@@ -979,7 +1168,7 @@ bool FileSystem::NeedLongPath(const char* path)
 }
 #endif
 
-CString FileSystem::MakeExtendedPath(const char* path, bool force)
+CString FileSystem::MakeExtendedPath(const char* path, [[maybe_unused]] bool force)
 {
 #ifdef WIN32
 	if (force || NeedLongPath(path))
@@ -994,7 +1183,7 @@ CString FileSystem::MakeExtendedPath(const char* path, bool force)
 		else
 		{
 			// local path
-			longpath.Format("\\\\?\\%s", canonicalPath);
+			longpath.Format("\\\\?\\%s", std::move(canonicalPath));
 		}
 		return *longpath;
 	}
@@ -1020,52 +1209,9 @@ CString FileSystem::WidePathToUtfPath(const wchar_t* wpath)
 #endif
 
 
-#ifdef WIN32
-DirBrowser::DirBrowser(const char* path)
-{
-	BString<1024> mask("%s%c*.*", path, PATH_SEPARATOR);
-	m_file = FindFirstFileW(FileSystem::UtfPathToWidePath(mask), &m_findData);
-	m_first = true;
-}
-
-DirBrowser::~DirBrowser()
-{
-	if (m_file != INVALID_HANDLE_VALUE)
-	{
-		FindClose(m_file);
-	}
-}
-
-const char* DirBrowser::InternNext()
-{
-	bool ok = false;
-	if (m_first)
-	{
-		ok = m_file != INVALID_HANDLE_VALUE;
-		m_first = false;
-	}
-	else
-	{
-		ok = FindNextFileW(m_file, &m_findData) != 0;
-	}
-	if (ok)
-	{
-		m_filename = FileSystem::WidePathToUtfPath(m_findData.cFileName);
-		return m_filename;
-	}
-	return nullptr;
-}
-
-#else
-
-#ifdef DIRBROWSER_SNAPSHOT
 DirBrowser::DirBrowser(const char* path, bool snapshot) :
 	m_snapshot(snapshot)
-#else
-DirBrowser::DirBrowser(const char* path)
-#endif
 {
-#ifdef DIRBROWSER_SNAPSHOT
 	if (m_snapshot)
 	{
 		DirBrowser dir(path, false);
@@ -1076,35 +1222,57 @@ DirBrowser::DirBrowser(const char* path)
 		m_snapshotIter = m_snapshotFiles.begin();
 	}
 	else
-#endif
 	{
+#ifdef WIN32
+		BString<1024> mask("%s%c*.*", path, PATH_SEPARATOR);
+		m_file = FindFirstFileW(FileSystem::UtfPathToWidePath(mask), &m_findData);
+		m_first = true;
+#else
 		m_dir = opendir(path);
+#endif
 	}
 }
 
 DirBrowser::~DirBrowser()
 {
-#ifdef DIRBROWSER_SNAPSHOT
-	if (!m_snapshot)
-#endif
+#ifdef WIN32
+	if (m_file != INVALID_HANDLE_VALUE)
 	{
-		if (m_dir)
-		{
-			closedir(m_dir);
-		}
+		FindClose(m_file);
 	}
+#else
+	if (m_dir)
+	{
+		closedir(m_dir);
+	}
+#endif
 }
 
 const char* DirBrowser::InternNext()
 {
-#ifdef DIRBROWSER_SNAPSHOT
 	if (m_snapshot)
 	{
 		return m_snapshotIter == m_snapshotFiles.end() ? nullptr : **m_snapshotIter++;
 	}
 	else
-#endif
 	{
+#ifdef WIN32
+		bool ok = false;
+		if (m_first)
+		{
+			ok = m_file != INVALID_HANDLE_VALUE;
+			m_first = false;
+		}
+		else
+		{
+			ok = FindNextFileW(m_file, &m_findData) != 0;
+		}
+		if (ok)
+		{
+			m_filename = FileSystem::WidePathToUtfPath(m_findData.cFileName);
+			return m_filename;
+		}
+#else
 		if (m_dir)
 		{
 			m_findData = readdir(m_dir);
@@ -1113,10 +1281,10 @@ const char* DirBrowser::InternNext()
 				return m_findData->d_name;
 			}
 		}
+#endif
 		return nullptr;
 	}
 }
-#endif
 
 const char* DirBrowser::Next()
 {
