@@ -1,8 +1,9 @@
 #!/bin/sh
 #
-#  This file is part of nzbget. See <http://nzbget.net>.
+#  This file is part of nzbget. See <https://nzbget.com>.
 #
 #  Copyright (C) 2015-2017 Andrey Prygunkov <hugbug@users.sourceforge.net>
+#  Copyright (C) 2024 phnzb <pavel@nzbget.com>
 #
 #  This program is free software; you can redistribute it and/or modify
 #  it under the terms of the GNU General Public License as published by
@@ -86,16 +87,18 @@ PrintHelp()
         Info "This installer supports Linux kernel 2.6 or newer and the following CPU architectures:"
     fi
     if test "$PLATFORM" = "freebsd"; then
-        Info "This installer supports FreeBSD 9.1 or newer and the following CPU architectures:"
+        Info "This installer supports FreeBSD 13 or newer and the following CPU architectures:"
     fi
     PrintArch "i686"     "    i686     - x86, 32 or 64 Bit"
     PrintArch "x86_64"   "    x86_64   - x86, 64 Bit"
     PrintArch "armel"    "    armel    - ARMv5/v6 (ARM9 and ARM11 families)"
     PrintArch "armhf"    "    armhf    - ARMv7/v8 (Cortex family)"
+    PrintArch "aarch64"  "    aarch64  - ARMv8, 64 Bit"
     PrintArch "mipsel"   "    mipsel   - MIPS (little endian)"
     PrintArch "mipseb"   "    mipseb   - MIPS (big endian)"
     PrintArch "ppc6xx"   "    ppc6xx   - PowerPC 6xx (603e series)"
     PrintArch "ppc500"   "    ppc500   - PowerPC e500 (core e500v1/e500v2)"
+    PrintArch "riscv64"  "    riscv64  - RISC-V 64-bit"
     Info ""
 
     # Check if command 'basename' is available and fallback to full path if it's not
@@ -188,12 +191,18 @@ DetectArch()
             armv5*|armv6*|armel)
                 ARCH=armel
                 ;;
-            armv7*|armv8*|aarch64)
+            armv7*|armv8*)
                 ARCH=armhf
                 ;;
+            aarch64)
+                ARCH=aarch64
+                ;;
             ppc)
                 ARCH=ppcx
                 ;;
+            riscv64)
+                ARCH=riscv64
+                ;;
         esac
     fi
 
@@ -247,6 +256,7 @@ Unpack()
             if test "$TARG" != "$ARCH"; then
                 echo "nzbget-$TARG" >> "$OUTDIR/installer.tmp"
                 echo "unrar-$TARG" >> "$OUTDIR/installer.tmp"
+                echo "unrar7-$TARG" >> "$OUTDIR/installer.tmp"
                 echo "7za-$TARG" >> "$OUTDIR/installer.tmp"
                 EXARCHS="-X installer.tmp"
             fi
@@ -266,9 +276,11 @@ Unpack()
         cd "$OUTDIR"
         rm -f nzbget
         rm -f unrar
+        rm -f unrar7
         rm -f 7za
         mv nzbget-$ARCH nzbget
         mv unrar-$ARCH unrar
+        mv unrar7-$ARCH unrar7
         mv 7za-$ARCH 7za
         echo "arch=$ARCH" > "installer.cfg"
         echo "select=$SELECT" >> "installer.cfg"
@@ -341,6 +353,8 @@ ConfigureLinux()
             sed 's:^WriteBuffer=.*:WriteBuffer=1024:' -i nzbget.conf
             Info "  Increasing par repair buffer (ParBuffer=100)"
             sed 's:^ParBuffer=.*:ParBuffer=100:' -i nzbget.conf
+            Info "  Activating direct rename (DirectRename=yes)"
+            sed 's:^DirectRename=.*:DirectRename=yes:' -i nzbget.conf
         elif test $TOTALFREE -gt 25000 -o $MEMFREE -gt 25000 -o $MEMCACHED -gt 25000; then
             Info "  Increasing write buffer (WriteBuffer=256)"
             sed 's:^WriteBuffer=.*:WriteBuffer=256:' -i nzbget.conf
@@ -368,6 +382,8 @@ ConfigureLinux()
             sed 's:^ScriptPauseQueue=.*:ScriptPauseQueue=yes:' -i nzbget.conf
         else
             Info "  Simultaneous download and post-processing is on"
+            Info "  Activating direct unpack (DirectUnpack=yes)"
+            sed 's:^DirectUnpack=.*:DirectUnpack=yes:' -i nzbget.conf
         fi
     fi
 }
@@ -384,6 +400,10 @@ ConfigureFreeBSD()
     sed -i '' 's:^WriteBuffer=.*:WriteBuffer=1024:' nzbget.conf
     Info "  Increasing par repair buffer (ParBuffer=100)"
     sed -i '' 's:^ParBuffer=.*:ParBuffer=100:' nzbget.conf
+    Info "  Activating direct rename (DirectRename=yes)"
+    sed -i '' 's:^DirectRename=.*:DirectRename=yes:' nzbget.conf
+    Info "  Activating direct unpack (DirectUnpack=yes)"
+    sed -i '' 's:^DirectUnpack=.*:DirectUnpack=yes:' nzbget.conf
 }
 
 Configure()
@@ -415,6 +435,7 @@ Linux2FreeBSD()
             Info "  Branding Linux binaries for use on FreeBSD"
             brandelf -t Linux nzbget
             brandelf -t Linux unrar
+            brandelf -t Linux unrar7
             brandelf -t Linux 7za
         fi
 
@@ -425,7 +446,7 @@ Linux2FreeBSD()
             fi
             if test "$MODLINUX" = ""; then
                 Info ""
-                Info "WARNING: Linux kernel module isn't loaded. See http://nzbget.net/installation-on-freebsd"
+                Info "WARNING: Linux kernel module isn't loaded. See https://nzbget.com/documentation/installation-on-freebsd/"
             fi
         fi
     fi
@@ -565,7 +586,7 @@ if test "$JUSTUNPACK" = "no"; then
     else
         Info "Successfully installed into $ABSOUTDIR"
     fi
-    Info "For support please visit http://nzbget.net/forum"
+    Info "For support please visit https://nzbget.com/forum/"
     Linux2FreeBSD "kernel-check"
 else
     Info "Unpacked into $ABSOUTDIR"
