@@ -1,7 +1,8 @@
 /*
- * This file is part of nzbget. See <http://nzbget.net>.
+ * This file is part of nzbget. See <https://nzbget.com>.
  *
- * Copyright (C) 2012-2016 Andrey Prygunkov <hugbug@users.sourceforge.net>
+ * Copyright (C) 2012-2019 Andrey Prygunkov <hugbug@users.sourceforge.net>
+ * Copyright (C) 2025 Denis <denis@nzbget.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -172,13 +173,9 @@ var Upload = (new function($)
 	{
 		var inp = $('#AddDialog_Input');
 
-		// Reset file input control; needed for IE10 but produce problems with opera (the old non-webkit one).
-		if ($.browser.msie)
-		{
-			inp.wrap('<form>').closest('form').get(0).reset();
-			inp.unwrap();
-		}
-		
+		// Reset file input control
+		inp.val('');		
+
 		inp.click();
 	}
 
@@ -194,15 +191,17 @@ var Upload = (new function($)
 
 	function addFiles(selectedFiles)
 	{
-		var list = '';
 		for (var i = 0; i<selectedFiles.length; i++)
 		{
 			var file = selectedFiles[i];
 			var filename = file.name.replace(/\.queued$/g, '');
 			var html = '<a class="link-black" href="#" onclick="Upload.renameClick(' + files.length + ')" title="Click to rename">'+
-				'<table><tr><td width="18px" valign="top"><i class="icon-file" style="vertical-align:top;margin-top:2px;">'+
-				'</i><img class="hide" style="vertical-align:top;margin-top:1px;" src="img/transmit-file.gif" width="16px" height="16px"></td>'+
-				'<td id="AddDialog_File' + files.length + '">' + Util.formatNZBName(filename) + '</td></tr></table></a>';
+				'<table><tr><td width="18px" valign="top">'+
+				'<i class="material-icon material-icon--draft">draft</i>'+
+				'<i class="material-icon material-icon--success hide">check_circle</i>'+
+				'<i class="material-icon material-icon--error hide">error</i>'+
+				'<i class="material-icon material-icon--progress spinner hide">progress_activity</i>'+
+				'</td><td id="AddDialog_File' + files.length + '">' + Util.formatNZBName(filename) + '</td></tr></table></a>';
 			$('#AddDialog_Files').append(html);
 			files.push(file);
 
@@ -223,7 +222,6 @@ var Upload = (new function($)
 	
 	this.renameClick = function(no)
 	{
-		var file = files[no];
 		var info = infos[no];
 		AddParamDialog.showModal(info, function() {
 			$('#AddDialog_File' + no).html(Util.formatNZBName(info.name + info.ext));
@@ -244,6 +242,7 @@ var Upload = (new function($)
 		$('#AddDialog_FilesHelp').show();
 		$('#AddDialog_URLLabel img').hide();
 		$('#AddDialog_URLLabel i').hide();
+		$('#AddDialog_AutoCategory').prop('checked', false);
 		$('#AddDialog_Paused').prop('checked', false);
 		$('#AddDialog_DupeForce').prop('checked', false);
 		enableAllButtons();
@@ -340,8 +339,8 @@ var Upload = (new function($)
 			return;
 		}
 
-		$('#AddDialog_Files table:eq(' + index + ') img').show();
-		$('#AddDialog_Files table:eq(' + index + ') i').hide();
+		$('#AddDialog_Files table:eq(' + index + ') i.material-icon--progress').toggleClass('hide');
+		$('#AddDialog_Files table:eq(' + index + ') i.material-icon--draft').toggleClass('hide');
 
 		var reader = new FileReader();
 		reader.onload = function (event)
@@ -359,9 +358,22 @@ var Upload = (new function($)
 			var priority = parseInt($('#AddDialog_Priority').val());
 			var filename = info.name + info.ext;
 			var addPaused = $('#AddDialog_Paused').is(':checked');
+			var autoCategory = $('#AddDialog_AutoCategory').is(':checked');
 			var dupeMode = $('#AddDialog_DupeForce').is(':checked') ? "FORCE" : "SCORE";
-			var params = info.password === '' ? [] : [{'*Unpack:password' : info.password}];
-			RPC.call('append', [filename, base64str, category, priority, false, addPaused, info.dupekey, info.dupescore, dupeMode, params], fileCompleted, fileFailure);
+			var params = info.password === '' ? [] : [{'*Unpack:Password' : info.password}];
+			RPC.call('append', [
+				filename,
+				base64str,
+				category,
+				priority,
+				false,
+				addPaused,
+				info.dupekey,
+				info.dupescore,
+				dupeMode,
+				autoCategory,
+				params,
+			], fileCompleted, fileFailure);
 		};
 
 		if (reader.readAsBinaryString)
@@ -382,10 +394,13 @@ var Upload = (new function($)
 		if (result)
 		{
 			filesSuccess.push(files[index]);
+			$('#AddDialog_Files table:eq(' + index + ') i.material-icon--success').toggleClass('hide');
 		}
-		$('#AddDialog_Files table:eq(' + index + ') img').hide();
-		$('#AddDialog_Files table:eq(' + index + ') i').removeClass('icon-file').addClass(
-			result ? 'icon-ok' : 'icon-remove').show();
+		else
+		{
+			$('#AddDialog_Files table:eq(' + index + ') i.material-icon--error').toggleClass('hide');
+		}
+		$('#AddDialog_Files table:eq(' + index + ') i.material-icon--progress').toggleClass('hide');
 		index++;
 		fileNext();
 	}
@@ -410,10 +425,23 @@ var Upload = (new function($)
 		
 		var category = $('#AddDialog_Category').val();
 		var priority = parseInt($('#AddDialog_Priority').val());
+		var autoCategory = $('#AddDialog_AutoCategory').is(':checked');
 		var addPaused = $('#AddDialog_Paused').is(':checked');
 		var dupeMode = $('#AddDialog_DupeForce').is(':checked') ? "FORCE" : "SCORE";
-		var params = urlInfo.password === '' ? [] : [{'*Unpack:password' : urlInfo.password}];
-		RPC.call('append', [urlInfo.name, url, category, priority, false, addPaused, urlInfo.dupekey, urlInfo.dupescore, dupeMode, params], urlCompleted, urlFailure);
+		var params = urlInfo.password === '' ? [] : [{'*Unpack:Password' : urlInfo.password}];
+		RPC.call('append', [
+			urlInfo.name,
+			url,
+			category,
+			priority,
+			false,
+			addPaused,
+			urlInfo.dupekey,
+			urlInfo.dupescore,
+			dupeMode,
+			autoCategory,
+			params,
+		], urlCompleted, urlFailure);
 	}
 
 	function urlCompleted(result)
